@@ -10,7 +10,11 @@ from .models import PandasDataset
 
 class PandasDatasetToTarFileSerializer(TarFileSerializer):
     @classmethod
-    def get_supported_dataset_type(cls) -> Type[Dataset]:
+    def is_dataset_directly_supported(cls, dataset: Dataset) -> bool:
+        return isinstance(dataset, PandasDataset)
+
+    @classmethod
+    def get_dataset_cls_for_new(cls) -> Type[Dataset]:
         return PandasDataset
 
     @classmethod
@@ -19,6 +23,8 @@ class PandasDatasetToTarFileSerializer(TarFileSerializer):
 
     @classmethod
     def serialize(cls, pandas_dataset: PandasDataset) -> Union[bytes, memoryview]:
+        assert isinstance(pandas_dataset, PandasDataset)
+
         def pandas_encode_func(pandas_data: pd.DataFrame) -> memoryview:
             csv_bytes = BytesIO()
             pandas_data.to_csv(csv_bytes, encoding='utf8', mode='b', index=False)
