@@ -1,6 +1,7 @@
 import inspect
 import os
 from pathlib import Path
+import sys
 
 
 def set_prefect_config_path():
@@ -10,7 +11,14 @@ def set_prefect_config_path():
         f"{Path(prefect_module_dir).joinpath('settings', 'logging.yml')}"
 
 
-# set_prefect_config_path()
+def use_local_api_for_tests():
+    if 'pytest' in sys.modules:
+        os.environ['PREFECT_API_KEY'] = ''
+        os.environ['PREFECT_API_URL'] = ''
+
+
+set_prefect_config_path()
+use_local_api_for_tests()
 
 from prefect import flow, Flow, State, task, Task
 from prefect.tasks import task_input_hash
